@@ -1,7 +1,7 @@
 """
 Type annotations for emr-containers service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/type_defs.html)
+[Open documentation](./type_defs.md)
 
 Usage::
 
@@ -15,7 +15,7 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List
 
-from mypy_boto3_emr_containers.literals import (
+from .literals import (
     EndpointState,
     FailureReason,
     JobRunState,
@@ -64,43 +64,86 @@ __all__ = (
 )
 
 CancelJobRunResponseTypeDef = TypedDict(
-    "CancelJobRunResponseTypeDef", {"id": str, "virtualClusterId": str}, total=False
+    "CancelJobRunResponseTypeDef",
+    {
+        "id": str,
+        "virtualClusterId": str,
+    },
+    total=False,
 )
 
-
-class _RequiredCloudWatchMonitoringConfigurationTypeDef(TypedDict):
-    logGroupName: str
+_RequiredCloudWatchMonitoringConfigurationTypeDef = TypedDict(
+    "_RequiredCloudWatchMonitoringConfigurationTypeDef",
+    {
+        "logGroupName": str,
+    },
+)
+_OptionalCloudWatchMonitoringConfigurationTypeDef = TypedDict(
+    "_OptionalCloudWatchMonitoringConfigurationTypeDef",
+    {
+        "logStreamNamePrefix": str,
+    },
+    total=False,
+)
 
 
 class CloudWatchMonitoringConfigurationTypeDef(
-    _RequiredCloudWatchMonitoringConfigurationTypeDef, total=False
+    _RequiredCloudWatchMonitoringConfigurationTypeDef,
+    _OptionalCloudWatchMonitoringConfigurationTypeDef,
 ):
-    logStreamNamePrefix: str
+    pass
 
 
-class ConfigurationOverridesTypeDef(TypedDict, total=False):
-    applicationConfiguration: List["ConfigurationTypeDef"]
-    monitoringConfiguration: "MonitoringConfigurationTypeDef"
+ConfigurationOverridesTypeDef = TypedDict(
+    "ConfigurationOverridesTypeDef",
+    {
+        "applicationConfiguration": List["ConfigurationTypeDef"],
+        "monitoringConfiguration": "MonitoringConfigurationTypeDef",
+    },
+    total=False,
+)
+
+_RequiredConfigurationTypeDef = TypedDict(
+    "_RequiredConfigurationTypeDef",
+    {
+        "classification": str,
+    },
+)
+_OptionalConfigurationTypeDef = TypedDict(
+    "_OptionalConfigurationTypeDef",
+    {
+        "properties": Dict[str, str],
+        "configurations": List[Dict[str, Any]],
+    },
+    total=False,
+)
 
 
-class _RequiredConfigurationTypeDef(TypedDict):
-    classification: str
+class ConfigurationTypeDef(_RequiredConfigurationTypeDef, _OptionalConfigurationTypeDef):
+    pass
 
 
-class ConfigurationTypeDef(_RequiredConfigurationTypeDef, total=False):
-    properties: Dict[str, str]
-    configurations: List[Dict[str, Any]]
-
-
-class ContainerInfoTypeDef(TypedDict, total=False):
-    eksInfo: "EksInfoTypeDef"
-
+ContainerInfoTypeDef = TypedDict(
+    "ContainerInfoTypeDef",
+    {
+        "eksInfo": "EksInfoTypeDef",
+    },
+    total=False,
+)
 
 _RequiredContainerProviderTypeDef = TypedDict(
-    "_RequiredContainerProviderTypeDef", {"type": Literal["EKS"], "id": str}
+    "_RequiredContainerProviderTypeDef",
+    {
+        "type": Literal["EKS"],
+        "id": str,
+    },
 )
 _OptionalContainerProviderTypeDef = TypedDict(
-    "_OptionalContainerProviderTypeDef", {"info": "ContainerInfoTypeDef"}, total=False
+    "_OptionalContainerProviderTypeDef",
+    {
+        "info": "ContainerInfoTypeDef",
+    },
+    total=False,
 )
 
 
@@ -112,38 +155,73 @@ class ContainerProviderTypeDef(
 
 CreateManagedEndpointResponseTypeDef = TypedDict(
     "CreateManagedEndpointResponseTypeDef",
-    {"id": str, "name": str, "arn": str, "virtualClusterId": str},
+    {
+        "id": str,
+        "name": str,
+        "arn": str,
+        "virtualClusterId": str,
+    },
     total=False,
 )
 
 CreateVirtualClusterResponseTypeDef = TypedDict(
-    "CreateVirtualClusterResponseTypeDef", {"id": str, "name": str, "arn": str}, total=False
+    "CreateVirtualClusterResponseTypeDef",
+    {
+        "id": str,
+        "name": str,
+        "arn": str,
+    },
+    total=False,
 )
 
 DeleteManagedEndpointResponseTypeDef = TypedDict(
-    "DeleteManagedEndpointResponseTypeDef", {"id": str, "virtualClusterId": str}, total=False
+    "DeleteManagedEndpointResponseTypeDef",
+    {
+        "id": str,
+        "virtualClusterId": str,
+    },
+    total=False,
 )
 
 DeleteVirtualClusterResponseTypeDef = TypedDict(
-    "DeleteVirtualClusterResponseTypeDef", {"id": str}, total=False
+    "DeleteVirtualClusterResponseTypeDef",
+    {
+        "id": str,
+    },
+    total=False,
 )
 
+DescribeJobRunResponseTypeDef = TypedDict(
+    "DescribeJobRunResponseTypeDef",
+    {
+        "jobRun": "JobRunTypeDef",
+    },
+    total=False,
+)
 
-class DescribeJobRunResponseTypeDef(TypedDict, total=False):
-    jobRun: "JobRunTypeDef"
+DescribeManagedEndpointResponseTypeDef = TypedDict(
+    "DescribeManagedEndpointResponseTypeDef",
+    {
+        "endpoint": "EndpointTypeDef",
+    },
+    total=False,
+)
 
+DescribeVirtualClusterResponseTypeDef = TypedDict(
+    "DescribeVirtualClusterResponseTypeDef",
+    {
+        "virtualCluster": "VirtualClusterTypeDef",
+    },
+    total=False,
+)
 
-class DescribeManagedEndpointResponseTypeDef(TypedDict, total=False):
-    endpoint: "EndpointTypeDef"
-
-
-class DescribeVirtualClusterResponseTypeDef(TypedDict, total=False):
-    virtualCluster: "VirtualClusterTypeDef"
-
-
-class EksInfoTypeDef(TypedDict, total=False):
-    namespace: str
-
+EksInfoTypeDef = TypedDict(
+    "EksInfoTypeDef",
+    {
+        "namespace": str,
+    },
+    total=False,
+)
 
 EndpointTypeDef = TypedDict(
     "EndpointTypeDef",
@@ -167,10 +245,13 @@ EndpointTypeDef = TypedDict(
     total=False,
 )
 
-
-class JobDriverTypeDef(TypedDict, total=False):
-    sparkSubmitJobDriver: "SparkSubmitJobDriverTypeDef"
-
+JobDriverTypeDef = TypedDict(
+    "JobDriverTypeDef",
+    {
+        "sparkSubmitJobDriver": "SparkSubmitJobDriverTypeDef",
+    },
+    total=False,
+)
 
 JobRunTypeDef = TypedDict(
     "JobRunTypeDef",
@@ -195,54 +276,98 @@ JobRunTypeDef = TypedDict(
     total=False,
 )
 
+ListJobRunsResponseTypeDef = TypedDict(
+    "ListJobRunsResponseTypeDef",
+    {
+        "jobRuns": List["JobRunTypeDef"],
+        "nextToken": str,
+    },
+    total=False,
+)
 
-class ListJobRunsResponseTypeDef(TypedDict, total=False):
-    jobRuns: List["JobRunTypeDef"]
-    nextToken: str
+ListManagedEndpointsResponseTypeDef = TypedDict(
+    "ListManagedEndpointsResponseTypeDef",
+    {
+        "endpoints": List["EndpointTypeDef"],
+        "nextToken": str,
+    },
+    total=False,
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+ListVirtualClustersResponseTypeDef = TypedDict(
+    "ListVirtualClustersResponseTypeDef",
+    {
+        "virtualClusters": List["VirtualClusterTypeDef"],
+        "nextToken": str,
+    },
+    total=False,
+)
+
+MonitoringConfigurationTypeDef = TypedDict(
+    "MonitoringConfigurationTypeDef",
+    {
+        "persistentAppUI": PersistentAppUI,
+        "cloudWatchMonitoringConfiguration": "CloudWatchMonitoringConfigurationTypeDef",
+        "s3MonitoringConfiguration": "S3MonitoringConfigurationTypeDef",
+    },
+    total=False,
+)
+
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
+)
+
+S3MonitoringConfigurationTypeDef = TypedDict(
+    "S3MonitoringConfigurationTypeDef",
+    {
+        "logUri": str,
+    },
+)
+
+_RequiredSparkSubmitJobDriverTypeDef = TypedDict(
+    "_RequiredSparkSubmitJobDriverTypeDef",
+    {
+        "entryPoint": str,
+    },
+)
+_OptionalSparkSubmitJobDriverTypeDef = TypedDict(
+    "_OptionalSparkSubmitJobDriverTypeDef",
+    {
+        "entryPointArguments": List[str],
+        "sparkSubmitParameters": str,
+    },
+    total=False,
+)
 
 
-class ListManagedEndpointsResponseTypeDef(TypedDict, total=False):
-    endpoints: List["EndpointTypeDef"]
-    nextToken: str
-
-
-class ListTagsForResourceResponseTypeDef(TypedDict, total=False):
-    tags: Dict[str, str]
-
-
-class ListVirtualClustersResponseTypeDef(TypedDict, total=False):
-    virtualClusters: List["VirtualClusterTypeDef"]
-    nextToken: str
-
-
-class MonitoringConfigurationTypeDef(TypedDict, total=False):
-    persistentAppUI: PersistentAppUI
-    cloudWatchMonitoringConfiguration: "CloudWatchMonitoringConfigurationTypeDef"
-    s3MonitoringConfiguration: "S3MonitoringConfigurationTypeDef"
-
-
-class PaginatorConfigTypeDef(TypedDict, total=False):
-    MaxItems: int
-    PageSize: int
-    StartingToken: str
-
-
-class S3MonitoringConfigurationTypeDef(TypedDict):
-    logUri: str
-
-
-class _RequiredSparkSubmitJobDriverTypeDef(TypedDict):
-    entryPoint: str
-
-
-class SparkSubmitJobDriverTypeDef(_RequiredSparkSubmitJobDriverTypeDef, total=False):
-    entryPointArguments: List[str]
-    sparkSubmitParameters: str
+class SparkSubmitJobDriverTypeDef(
+    _RequiredSparkSubmitJobDriverTypeDef, _OptionalSparkSubmitJobDriverTypeDef
+):
+    pass
 
 
 StartJobRunResponseTypeDef = TypedDict(
     "StartJobRunResponseTypeDef",
-    {"id": str, "name": str, "arn": str, "virtualClusterId": str},
+    {
+        "id": str,
+        "name": str,
+        "arn": str,
+        "virtualClusterId": str,
+    },
     total=False,
 )
 
